summaryrefslogtreecommitdiffstats
path: root/ksquirrel/sq_slideshowlisting.ui.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksquirrel/sq_slideshowlisting.ui.h')
-rw-r--r--ksquirrel/sq_slideshowlisting.ui.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksquirrel/sq_slideshowlisting.ui.h b/ksquirrel/sq_slideshowlisting.ui.h
index 4608f8b..5b57c2a 100644
--- a/ksquirrel/sq_slideshowlisting.ui.h
+++ b/ksquirrel/sq_slideshowlisting.ui.h
@@ -2,7 +2,7 @@
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
@@ -12,11 +12,11 @@
void SQ_SlideShowListing::init()
{
- connect(pushCancel, SIGNAL(clicked()), this, SIGNAL(kill()));
+ connect(pushCancel, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(kill()));
}
-void SQ_SlideShowListing::setFile(int count, const QString &f)
+void SQ_SlideShowListing::setFile(int count, const TQString &f)
{
- textCount->setText(QString::fromLatin1("[%1]").arg(count));
+ textCount->setText(TQString::tqfromLatin1("[%1]").tqarg(count));
textFile->setText(f);
}
@@ -2,7 +2,7 @@
**
** If you want to add, delete, or rename functions or slots, use
-** Qt Designer to update this file, preserving your code.
+** TQt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.